.. currentmodule:: index_calculator

"""""""""""""
API reference
"""""""""""""

This page provides an auto-generated summary of the index_calculator API.

Top-level classes and functions
===============================

.. autosummary::
   :toctree: generated/

   preprocessing
   processing
   postprocessing
   outputwriter
   index_calculator
